# OneLine-GPT

A command line tool used to perform search or talk with GPT3.5.

Install:

```
pip install olgpt
```

Run `search` mode: Contextless chat with GPT, no history, cheaper.
```
olgpt s
```
or 
```
olgpt search
```

Run `chat` mode: Chat with GPT with history, support longer conversation.
```
olgpt c
```
or 
```
olgpt chat
```